pub struct HttpTransportServer { /* private fields */ }Expand description
Unidirectional HTTP transport server used for request-response type of communication by clients for which a full libp2p transport is impossible.
Since it doesn’t run a full fledge transport, authentication is achieved
through a generated AuthToken signed by the public key of a node of the
cell.
At the moment, this transport is only used for entity queries and mutations.
Implementations
Sourceimpl HttpTransportServer
impl HttpTransportServer
Sourcepub fn new(
local_node: LocalNode,
config: HttpTransportConfig,
clock: Clock,
) -> HttpTransportServer
pub fn new( local_node: LocalNode, config: HttpTransportConfig, clock: Clock, ) -> HttpTransportServer
Creates a new HTTP server with the given configuration and clock.
Sourcepub fn get_handle(
&mut self,
cell: Cell,
service_type: ServiceType,
) -> Result<HttpTransportServiceHandle, Error>
pub fn get_handle( &mut self, cell: Cell, service_type: ServiceType, ) -> Result<HttpTransportServiceHandle, Error>
Get a transport handle that will be used by services. This handle can only be used to receive messages and reply to them.